#!/usr/bin/env python

from os.path import dirname, join, realpath
from setuptools import setup, find_packages

from karabo.packaging.versioning import device_scm_version


ROOT_FOLDER = dirname(realpath(__file__))
scm_version = device_scm_version(
    ROOT_FOLDER,
    join(ROOT_FOLDER, 'src', 'calng', '_version.py')
)


setup(name='calng',
      use_scm_version=scm_version,
      author='CAL team',
      author_email='da-support@xfel.eu',
      description='',
      long_description='',
      url='',
      package_dir={'': 'src'},
      packages=find_packages('src'),
      entry_points={
          'karabo.bound_device': [
              'AgipdCorrection = calng.AgipdCorrection:AgipdCorrection',
              'ManualAgipdGeometry = calng.AgipdCorrection:ManualAgipdGeometry',
              'DsscCorrection = calng.DsscCorrection:DsscCorrection',
              'ManualDsscGeometry = calng.DsscCorrection:ManualDsscGeometry',
              'JungfrauCorrection = calng.JungfrauCorrection:JungfrauCorrection',
              'ManualJungfrauGeometry = calng.JungfrauCorrection:ManualJungfrauGeometry',
              'ShmemToZMQ = calng.ShmemToZMQ:ShmemToZMQ',
              'ShmemTrainMatcher = calng.ShmemTrainMatcher:ShmemTrainMatcher',
              'DetectorAssembler = calng.DetectorAssembler:DetectorAssembler',
          ],

          'karabo.middlelayer_device': [
              'CalibrationManager = calng.CalibrationManager:CalibrationManager'
          ],
      },
      package_data={'': ['kernels/*']},
      requires=[],
)
